import os
import sys
sys.path.append(os.path.join('..', 'pyJacqQ'))
import jacqq

details = os.path.join('pyJacqQ', 'tests', 'simulation_data', 'input_details.csv')
histories = os.path.join('pyJacqQ', 'tests', 'simulation_data', 'input_residence_histories.csv')
focus = os.path.join('pyJacqQ', 'tests', 'simulation_data', 'input_focus.csv')

errors = jacqq.check_data_dirty(details, histories, focus, exposure=True, weights=True)
print("Errors:", errors)
print("Crunching numbers...")
study = jacqq.QStatsStudy(details, histories, focus)
results = study.run_analysis(k=5, use_exposure=True, use_weights=True, correction="BINOM", seed = 4077096852)

print("Exposure calculated", results.exposure_enabled)
print("Alpha", results.adjusted_alpha)
print("#Permutations", results.number_permutation_shuffles)
print("Seed:", results.seed)
print("Q:", results.Q_case_years)
print("Normalized Qf:", results.normalized_Qf)
print("Time slices", results.time_slices)
print("Qt for Jan 3rd, 2015:", results.time_slices[20150103].stat)
print("Sig Qt for Jan 3rd, 2015:", results.time_slices[20150103].sig_points)
print("Local Qit for 'BM' on Jan 3rd, 2015:")
print(results.time_slices[20150103].points['BM'].stat, results.cases['BM'].points[20150103].stat)
print("Significant Qit for 'BM'", results.cases['BM'].sig_points)
print("X, Y location of 'BM' on Jan 2nd, 2015:", results.cases['BM'].points[20150102].loc)
print("Focus tabular data:", results.get_tabular_focus_data())
print("Binomial results for dates:", results.binom.dates)
print("Slices < k+1 points:", results.dates_lower_k_plus_one)
print("Saving results with 'my_study_prefix' to 'path/to/my_results_folder'")
results.write_to_files_prefixed('path/to/my_results_folder', 'my_study_prefix')
print("Saving files using individual names to base directory")
results.write_to_files('global.csv', 'cases.csv', 'dates.csv', 'local_cases.csv', 'focus_results.csv', 'focus_local.csv')
